distcheck

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2026 License: MIT Imports: 21 Imported by: 0

Documentation

Overview

Package distcheck verifies that an Envguard distribution is complete and internally consistent before any artifact is published.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Verify

func Verify(directory string, smoke bool) error

Verify checks the complete release matrix, archive contents, and checksums. When smoke is true, the executable for the current host target is also run.

Types

This section is empty.

Jump to